@@ -5,25 +5,24 @@
 # as set forth in the License.
 
 
-
-
 """
 This module contains a number of utilities for working with
 dates and times, in conjunction with the python `datetime` module.
-
 """
+
 from __future__ import absolute_import
-from datetime import datetime, timedelta, tzinfo
-from decimal import Decimal
+
+import re
 import time
 import calendar
-import re
+from datetime import datetime, timedelta, tzinfo
+from decimal import Decimal
 
-__all__ = [ 'ensure_timezone', 'force_to_utc', 'datetime_to_seconds', 
-            'datetime_to_microseconds', 'datetime_to_nanoseconds',
-            'usec_string_to_datetime', 'nsec_string_to_datetime',
-            'timedelta_total_seconds', 'timedelta_str',
-            'TimeParser', 'parse_timedelta', 'parse_range' ]
+__all__ = ['ensure_timezone', 'force_to_utc', 'datetime_to_seconds',
+           'datetime_to_microseconds', 'datetime_to_nanoseconds',
+           'usec_string_to_datetime', 'nsec_string_to_datetime',
+           'timedelta_total_seconds', 'timedelta_str',
+           'TimeParser', 'parse_timedelta', 'parse_range']
 
 
 #
@@ -34,11 +33,12 @@ __all__ = [ 'ensure_timezone', 'force_to_utc', 'datetime_to_seconds',
 ZERO = timedelta(0)
 EPOCHORDINAL = datetime.utcfromtimestamp(0).toordinal()
 
+
 class tzutc(tzinfo):
 
     def utcoffset(self, dt):
         return ZERO
-     
+
     def dst(self, dt):
         return ZERO
 
@@ -50,6 +50,7 @@ class tzutc(tzinfo):
 
     __reduce__ = object.__reduce__
 
+
 class tzlocal(tzinfo):
 
     _std_offset = timedelta(seconds=-time.timezone)
@@ -76,25 +77,25 @@ class tzlocal(tzinfo):
     def _isdst(self, dt):
         # We can't use mktime here. It is unstable when deciding if
         # the hour near to a change is DST or not.
-        # 
+        #
         # timestamp = time.mktime((dt.year, dt.month, dt.day, dt.hour,
         #                         dt.minute, dt.second, dt.weekday(), 0, -1))
         # return time.localtime(timestamp).tm_isdst
         #
         # The code above yields the following result:
         #
-        #>>> import tz, datetime
-        #>>> t = tz.tzlocal()
-        #>>> datetime.datetime(2003,2,15,23,tzinfo=t).tzname()
-        #'BRDT'
-        #>>> datetime.datetime(2003,2,16,0,tzinfo=t).tzname()
-        #'BRST'
-        #>>> datetime.datetime(2003,2,15,23,tzinfo=t).tzname()
-        #'BRST'
-        #>>> datetime.datetime(2003,2,15,22,tzinfo=t).tzname()
-        #'BRDT'
-        #>>> datetime.datetime(2003,2,15,23,tzinfo=t).tzname()
-        #'BRDT'
+        # >>> import tz, datetime
+        # >>> t = tz.tzlocal()
+        # >>> datetime.datetime(2003,2,15,23,tzinfo=t).tzname()
+        # 'BRDT'
+        # >>> datetime.datetime(2003,2,16,0,tzinfo=t).tzname()
+        # 'BRST'
+        # >>> datetime.datetime(2003,2,15,23,tzinfo=t).tzname()
+        # 'BRST'
+        # >>> datetime.datetime(2003,2,15,22,tzinfo=t).tzname()
+        # 'BRDT'
+        # >>> datetime.datetime(2003,2,15,23,tzinfo=t).tzname()
+        # 'BRDT'
         #
         # Here is a more stable implementation:
         #
@@ -120,77 +121,92 @@ class tzlocal(tzinfo):
 
 
 def ensure_timezone(dt):
-    """ Return a datetime object that corresponds to `dt`
-    but that always has timezone info.  If `dt` already
-    has timezone info, then it is simply returned.  If `dt`
-    does not have timezone info, then the local time zone is
-    assumed."""
+    """Return a datetime object that corresponds to `dt` but that always has
+    timezone info.
+
+    If `dt` already has timezone info, then it is simply returned.
+    If `dt` does not have timezone info, then the local time zone is assumed.
+    """
 
     if dt.tzinfo is not None:
         return dt
 
     return dt.replace(tzinfo=tzlocal())
 
+
 def force_to_utc(dt):
-    """ Return a datetime object that corresponds to `dt`
-    but in UTC rather than local time.
-    If `dt` includes timezone info, then this routine simply
-    converts from the given timezone to UTC.
-    If `dt` does not include timezone info, then it is assumed
-    to be in local time, which is then converted to UTC."""
+    """Return a datetime object that corresponds to `dt` but in UTC rather than
+    local time.
+
+    If `dt` includes timezone info, then this routine simply converts from the
+    given timezone to UTC.
+    If `dt` does not include timezone info, then it is assumed to be in local
+    time, which is then converted to UTC.
+    """
 
     return ensure_timezone(dt).astimezone(tzutc())
-    
-def datetime_to_seconds(dt):
-    """ Return the number of seconds since the Unix epoch
-    for the datetime object `dt` """
 
+
+def datetime_to_seconds(dt):
+    """Return the number of seconds since the Unix epoch for
+    the datetime object `dt`.
+    """
     dt = ensure_timezone(dt)
-    
+
     sec = int(calendar.timegm(dt.utctimetuple()))
     return sec
 
-def datetime_to_microseconds(dt):
-    """ Return the number of microseconds since the Unix epoch
-    for the datetime object `dt` """
 
+def datetime_to_microseconds(dt):
+    """Return the number of microseconds since the Unix epoch for
+    the datetime object `dt`.
+    """
     dt = ensure_timezone(dt)
-    
+
     sec = int(calendar.timegm(dt.utctimetuple()))
     return sec * 1000000 + dt.microsecond
 
-def datetime_to_nanoseconds(dt):
-    """ Return the number of nanoseconds since the Unix epoch
-    for the datetime object `dt` """
 
+def datetime_to_nanoseconds(dt):
+    """Return the number of nanoseconds since the Unix epoch for
+    the datetime object `dt`.
+    """
     dt = ensure_timezone(dt)
-    
+
     if not hasattr(dt, 'nanosecond'):
         return 1000 * datetime_to_microseconds(dt)
 
     return int(calendar.timegm(dt.utctimetuple()))*1000000000+dt.nanosecond
 
+
 def sec_string_to_datetime(s):
-    """ Convert the string `s` which represents a time in seconds
-    since the Unix epoch to a datetime object """
+    """Convert the string `s` which represents a time in seconds
+    since the Unix epoch to a datetime object.
+    """
     return datetime.fromtimestamp(s, tzutc())
 
+
 def msec_string_to_datetime(s):
-    """ Convert the string `s` which represents a time in milliseconds
-    since the Unix epoch to a datetime object """
+    """Convert the string `s` which represents a time in milliseconds
+    since the Unix epoch to a datetime object.
+    """
     sec = Decimal(s) / Decimal(1000)
     return datetime.fromtimestamp(sec, tzutc())
 
+
 def usec_string_to_datetime(s):
-    """ Convert the string `s` which represents a time in microseconds
-    since the Unix epoch to a datetime object """
+    """Convert the string `s` which represents a time in microseconds
+    since the Unix epoch to a datetime object.
+    """
     sec = Decimal(s) / Decimal(1000000)
     return datetime.fromtimestamp(sec, tzutc())
-    
+
+
 def nsec_to_datetime(ns):
     """Convert the value `ns` which represents a time in nanoseconds
     since the Unix epoch (either as an integer or a string) to a
-    datetime object"""
+    datetime object.
+    """
     if isinstance(ns, str):
         ns = int(ns)
     if ns == 0:
@@ -209,6 +225,7 @@ def nsec_to_datetime(ns):
 
     return datetime.fromtimestamp(sec, tzutc())
 
+
 def string_to_datetime(s):
     """Determine level of precision by number of digits and return
     a datetime object.
@@ -233,22 +250,26 @@ def string_to_datetime(s):
 # XXX/demmer remove this
 nsec_string_to_datetime = nsec_to_datetime
 
+
 def usec_string_to_timedelta(s):
-    """ Convert the string `s` which represents a number of microseconds
-    to a timedelta object """
+    """Convert the string `s` which represents a number of microseconds
+    to a timedelta object.
+    """
     sec = float(s) / 1000000
     return timedelta(seconds=sec)
 
+
 def timedelta_total_seconds(td):
-    """ Handle backwards compatability for timedelta.total_seconds."""
+    """Handle backwards compatibility for timedelta.total_seconds."""
     if hasattr(td, 'total_seconds'):
         return td.total_seconds()
     return float(td.microseconds + (td.seconds + td.days * 24 * 3600) * 10**6) / 10**6
 
 
 class TimeParser(object):
-    """ Instances of this class parse strings representing dates and/or
+    """Instances of this class parse strings representing dates and/or
     times into python `datetime.datetime` objects.
+
     This class is capable of parsing a variety of different formats.
     On the first call, the method `parse()` may take some time, as it
     tries a series of pre-defined formats one after another.  After
@@ -262,11 +283,12 @@ class TimeParser(object):
 
     @classmethod
     def _parse_no_hint(cls, s):
-        """ parse string s as a date/time without any hint about the format.
+        """Parse string s as a date/time without any hint about the format.
+
         If it can be parsed, returns a tuple of the datetime object
         and the format object that was used.  If the string cannot be
-        parsed, raises ValueError. """
-        
+        parsed, raises ValueError.
+        """
         for fmt in cls._formats:
             try:
                 dt = fmt.match(s)
@@ -278,18 +300,19 @@ class TimeParser(object):
 
     @classmethod
     def parse_one(cls, s):
-        """ do a "one-shot" parsing of string s as a date/time.
-        doesn't remember anything about the format that was used. """
+        """Do a "one-shot" parsing of string s as a date/time.
+
+        Doesn't remember anything about the format that was used.
+        """
         dt, ignored = cls._parse_no_hint(s)
         return dt
 
     def parse(self, s):
+        """Parse the string `s` as a date and time.
+
+        Returns a `datetime.datetime` object on success or raises `ValueError`
+        if the string cannot be parsed.
         """
-        Parse the string `s` as a date and time.  Returns a
-        `datetime.datetime` object on success or raises
-        `ValueError` if the string cannot be parsed.
-        """
-        
         # begin with some normalization, strip whitespace and convert
         # dashes to slashes so that 05-10-2011 is equivalent to 05/10/2011
         s = s.strip().replace('-', '/')
@@ -339,42 +362,44 @@ class TimeParser(object):
             self.pattern = pattern
             self.has_date = has_date
             self.has_year = has_year
-            if has_year: assert has_date
+            if has_year:
+                assert has_date
 
         def match(self, s):
             tm = datetime.strptime(s, self.pattern)
 
             if self.has_year:
                 return tm
-            
+
             now = datetime.now()
             if self.has_date:
                 return tm.replace(year=now.year)
 
             return tm.replace(month=now.month, day=now.day, year=now.year)
 
-    _formats = [ _informat(_tf, False, False) for _tf in _time_formats ] \
-               + [ _informat('%s %s' % (_tf, _df), True, False)
-                   for _tf in _time_formats for _df in _date_formats ] \
-               + [ _informat('%s %s' % (_df, _tf), True, False)
-                   for _tf in _time_formats for _df in _date_formats ] \
-               + [ _informat('%s %s' % (_tf, _df), True, True)
-                   for _tf in _time_formats for _df in _date_year_formats ] \
-               + [ _informat('%s %s' % (_df, _tf), True, True)
-                   for _tf in _time_formats for _df in _date_year_formats ]
+    _formats = ([_informat(_tf, False, False) for _tf in _time_formats]
+                + [_informat('%s %s' % (_tf, _df), True, False)
+                   for _tf in _time_formats for _df in _date_formats]
+                + [_informat('%s %s' % (_df, _tf), True, False)
+                   for _tf in _time_formats for _df in _date_formats]
+                + [_informat('%s %s' % (_tf, _df), True, True)
+                   for _tf in _time_formats for _df in _date_year_formats]
+                + [_informat('%s %s' % (_df, _tf), True, True)
+                   for _tf in _time_formats for _df in _date_year_formats])
 
 _timedelta_units = {
-    'us' : 0.000001, 'usec' : 0.000001, 'microsecond' : 0.000001, 'microseconds' : 0.000001,
-    'ms' : 0.001, 'msec' : 0.001, 'millisecond' : 0.001, 'milliseconds' : 0.001,
-    's' : 1, 'sec' : 1, 'second' : 1, 'seconds' : 1,
-    'm' : 60, 'min' : 60, 'minute' : 60, 'minutes' : 60,
-    'h' : 60*60, 'hr' : 60*60, 'hour' : 60*60, 'hours' : 60*60,
-    'd' : 24*60*60, 'day' : 24*60*60, 'days': 24*60*60,
-    'w' : 7*24*60*60, 'week' : 7*24*60*60, 'weeks': 7*24*60*60,
+    'us': 0.000001, 'usec': 0.000001, 'microsecond': 0.000001, 'microseconds': 0.000001,
+    'ms': 0.001, 'msec': 0.001, 'millisecond': 0.001, 'milliseconds': 0.001,
+    's': 1, 'sec': 1, 'second': 1, 'seconds': 1,
+    'm': 60, 'min': 60, 'minute': 60, 'minutes': 60,
+    'h': 60*60, 'hr': 60*60, 'hour': 60*60, 'hours': 60*60,
+    'd': 24*60*60, 'day': 24*60*60, 'days': 24*60*60,
+    'w': 7*24*60*60, 'week': 7*24*60*60, 'weeks': 7*24*60*60,
 }
 
 _timedelta_re = re.compile("([0-9]*\.*[0-9]*) *([a-zA-Z]*)")
 
+
 def timedelta_str(td):
     def pluralize(val, base, plural):
         if val > 1:
@@ -384,14 +409,18 @@ def timedelta_str(td):
 
     if td.days > 0:
         if td.seconds != 0 or td.microseconds != 0:
-            raise ValueError("Timedelta has too many components for pretty string: %s" % str(td))
+            msg = ("Timedelta has too many components for pretty string: %s"
+                   % str(td))
+            raise ValueError(msg)
         if td.days % 7 == 0:
             return pluralize(td.days / 7, "week", "weeks")
         else:
             return pluralize(td.days, "day", "days")
     elif td.seconds > 0:
         if td.microseconds != 0:
-            raise ValueError("Timedelta has too many components for pretty string: %s" % str(td))
+            msg = ("Timedelta has too many components for pretty string: %s"
+                   % str(td))
+            raise ValueError(msg)
         if td.seconds % (60*60) == 0:
             return pluralize(td.seconds / (60*60), "hour", "hours")
         elif td.seconds % 60 == 0:
@@ -400,15 +429,18 @@ def timedelta_str(td):
             return pluralize(td.seconds, "second", "seconds")
     else:
         if td.microseconds % 1000 == 0:
-            return pluralize(td.microseconds / 1000, "millisecond", "milliseconds")
+            return pluralize(
+                td.microseconds / 1000, "millisecond", "milliseconds"
+            )
         else:
             return pluralize(td.microseconds, "microsecond", "microseconds")
 
 
 def round_time(dt=None, round_to=60, round_up=False, trim=False):
-    """Round a datetime object to any time laps in seconds
-    `dt` : datetime.datetime object, default now.
-    `round_to` : Closest number of seconds to round to, default 1 minute.
+    """Round a datetime object to any time laps in seconds.
+
+    `dt`: datetime.datetime object, default now.
+    `round_to`: Closest number of seconds to round to, default 1 minute.
     `round_up`: Default rounds down to nearest `round_to` interval,
                True here will instead round up.
     `trim`: Trim to nearest round_to value rather than rounding.
@@ -432,12 +464,13 @@ def round_time(dt=None, round_to=60, round_up=False, trim=False):
 
 
 def parse_timedelta(s):
-    """ Parse the string `s` representing some duration of time
+    """Parse the string `s` representing some duration of time
     (e.g., `"3 seconds"` or `"1 week"`) and return a `datetime.timedelta`
     object representing that length of time.
+
     If the string cannot be parsed, raises `ValueError`.
     """
-    
+
     m = _timedelta_re.match(s)
     if not m:
         raise ValueError("Could not parse string as timedelta: %s" % s)
@@ -446,7 +479,7 @@ def parse_timedelta(s):
         val = 1
     else:
         val = float(m.group(1))
-        
+
     if m.group(2) == "":
         units = 1
     else:
@@ -456,11 +489,12 @@ def parse_timedelta(s):
             raise ValueError("Invalid timedelta units: %s" % m.group(2))
 
     return timedelta(seconds=units * float(val))
-    
+
 
 def parse_range(s):
-    """ Parse the string `s` representing a range of times
+    """Parse the string `s` representing a range of times
     (e.g., `"12:00 PM to 1:00 PM"` or `"last 2 weeks"`).
+
     Upon success returns a pair of `datetime.datetime` objects
     representing the beginning and end of the time range.
     If the string cannot be parsed, raises `ValueError`.
@@ -508,7 +542,7 @@ def parse_range(s):
             pass
 
     raise ValueError('cannot parse time range "%s"' % s)
-    
+
 
 # XXX probably incorrect in some locales?
 _fmt_widths = {
@@ -517,13 +551,14 @@ _fmt_widths = {
     'm': 2, 'M': 2, 'p': 2, 'S': 2, 'U': 2,
     'w': 1, 'W': 2, 'x': 8, 'X': 8, 'y': 2,
     'Y': 4, 'z': 5, 'Z': 3, '%': 1
-    }
+}
+
 
 def max_width(fmt):
-    """ Given a time formatting string (i.e., a string that can be
+    """Given a time formatting string (i.e., a string that can be
     used as the `fmt` option to `datetime.strftime`, compute the
-    maximum length of a formatted date string """
-
+    maximum length of a formatted date string.
+    """
     m = 0
     i = 0
     while i < len(fmt):
@@ -532,7 +567,9 @@ def max_width(fmt):
                 i += 1
                 m += _fmt_widths[fmt[i]]
             except IndexError:
-                raise ValueError('do not understand %%%s in format string' % fmt[i])
+                raise ValueError(
+                    'do not understand %%%s in format string' % fmt[i]
+                )
         else:
             m += 1
 
